@@ -140,6 +140,7 @@ impl<'a> Parser<'a> {
             "rule" => Def::Rule(self.parse_rule()?),
             "extractor" => Def::Extractor(self.parse_etor()?),
             "extern" => Def::Extern(self.parse_extern()?),
+            "convert" => Def::Converter(self.parse_converter()?),
             s => {
                 return Err(self.error(pos, format!("Unexpected identifier: {}", s)));
             }
@@ -515,4 +516,17 @@ impl<'a> Parser<'a> {
         self.rparen()?;
         Ok(LetDef { var, ty, val, pos })
     }
+
+    fn parse_converter(&mut self) -> Result<Converter> {
+        let pos = self.pos();
+        let inner_ty = self.parse_ident()?;
+        let outer_ty = self.parse_ident()?;
+        let term = self.parse_ident()?;
+        Ok(Converter {
+            term,
+            inner_ty,
+            outer_ty,
+            pos,
+        })
+    }
 }
